@@ -1,5 +1,4 @@
 # pylint: disable=missing-module-docstring
-from typing import Optional
 from datetime import datetime
 import requests
 from dwh_oppfolging.misc.transforms import dict_to_string, string_to_sha256_hash, string_to_naive_norwegian_datetime
@@ -21,7 +20,7 @@ _VALID_DATE_FMT = "%Y-%m-%d"
 _MODIFIED_DATE_FMT = "%Y-%m-%dT%H:%M:%S.%f%z"
 
 
-def _convert_ssb_date(date: Optional[str], fmt: str):
+def _convert_ssb_date(date: str | None, fmt: str):
     """converts ssb date string to datetime"""
     if date is None:
         return None
